@@ -3,6 +3,7 @@ from .api.core import (
     collapse_alleles,
     has_phenotype,
     has_score,
+    has_sv,
     is_legit_allele,
     is_target_gene,
     get_default_allele,
@@ -11,6 +12,7 @@ from .api.core import (
     get_function,
     get_paralog,
     get_priority,
+    get_recommendation,
     get_ref_allele,
     get_region,
     get_score,
@@ -29,6 +31,7 @@ from .api.core import (
     load_equation_table,
     load_gene_table,
     load_phenotype_table,
+    load_recommendation_table,
     load_variant_table,
     predict_phenotype,
     predict_score,
