@@ -34,7 +34,8 @@ CovFrame[CopyNumber]."""
         '--path',
         metavar='PATH',
         help=
-"""Create plots in this directory."""
+"""Create plots in this directory (default: current
+directory)."""
     )
     parser.add_argument(
         '--samples',
